@@ -18,6 +18,7 @@ import os
 import shutil
 import six
 from six.moves import configparser
+from six.moves import cStringIO as StringIO
 import subprocess
 import tempfile
 import time
@@ -36,7 +37,8 @@ def write_default_ansible_cfg(work_dir,
                               remote_user,
                               ssh_private_key=None,
                               transport=None,
-                              base_ansible_cfg='/etc/ansible/ansible.cfg'):
+                              base_ansible_cfg='/etc/ansible/ansible.cfg',
+                              override_ansible_cfg=None):
     ansible_config_path = os.path.join(work_dir, 'ansible.cfg')
     shutil.copy(base_ansible_cfg, ansible_config_path)
 
@@ -48,13 +50,16 @@ def write_default_ansible_cfg(work_dir,
                os.path.join(work_dir, 'ansible.log'))
     config.set('defaults', 'forks', '25')
     config.set('defaults', 'timeout', '30')
+    config.set('defaults', 'gather_timeout', '30')
 
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
                '-o UserKnownHostsFile=/dev/null '
                '-o StrictHostKeyChecking=no '
                '-o ControlMaster=auto '
-               '-o ControlPersist=30m')
+               '-o ControlPersist=30m '
+               '-o ServerAliveInterval=5 '
+               '-o ServerAliveCountMax=5')
     config.set('ssh_connection', 'control_path_dir',
                os.path.join(work_dir, 'ansible-ssh'))
     config.set('ssh_connection', 'retries', '8')
@@ -69,6 +74,13 @@ def write_default_ansible_cfg(work_dir,
     if transport:
         config.set('defaults', 'transport', transport)
 
+    if override_ansible_cfg:
+        sio_cfg = StringIO()
+        sio_cfg.write(override_ansible_cfg)
+        sio_cfg.seek(0)
+        config.readfp(sio_cfg)
+        sio_cfg.close()
+
     with open(ansible_config_path, 'w') as configfile:
         config.write(configfile)
 
@@ -83,7 +95,7 @@ class AnsibleAction(actions.Action):
         self.hosts = self._kwargs_for_run.pop('hosts', None)
         self.module = self._kwargs_for_run.pop('module', None)
         self.module_args = self._kwargs_for_run.pop('module_args', None)
-        if self.module_args:
+        if self.module_args and isinstance(self.module_args, dict):
             self.module_args = json.dumps(self.module_args)
         self.limit_hosts = self._kwargs_for_run.pop('limit_hosts', None)
         self.remote_user = self._kwargs_for_run.pop('remote_user', None)
@@ -305,6 +317,10 @@ class AnsiblePlaybookAction(base.TripleOAction):
             'profile_tasks_limit', 0)
         self.blacklisted_hostnames = self._kwargs_for_run.pop(
             'blacklisted_hostnames', [])
+        self.override_ansible_cfg = self._kwargs_for_run.pop(
+            'override_ansible_cfg', None)
+        self.command_timeout = self._kwargs_for_run.pop(
+            'command_timeout', None)
 
     @property
     def work_dir(self):
@@ -484,7 +500,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
             ansible_config_path = write_default_ansible_cfg(
                 self.work_dir,
                 self.remote_user,
-                ssh_private_key=self.ssh_private_key)
+                ssh_private_key=self.ssh_private_key,
+                override_ansible_cfg=self.override_ansible_cfg)
             env_variables = {
                 'HOME': self.work_dir,
                 'ANSIBLE_LOCAL_TEMP': self.work_dir,
@@ -511,6 +528,9 @@ class AnsiblePlaybookAction(base.TripleOAction):
                     'OS_AUTH_TOKEN': security_ctx.auth_token,
                     'OS_PROJECT_NAME': security_ctx.project_name})
 
+            if self.command_timeout:
+                command = ['timeout', self.command_timeout] + command
+
             command = [str(c) for c in command]
 
             if self.reproduce_command:
