@@ -33,6 +33,12 @@ TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
                              'overcloud_containers.yaml.j2')
 
 
+DEFAULTS_PATH = os.path.join(os.path.dirname(__file__),
+                             '..', '..', '..', 'container-images',
+                             'container_image_prepare_defaults.yaml')
+kb.init_prepare_defaults(DEFAULTS_PATH)
+
+
 filedata = six.u("""container_images:
 - imagename: docker.io/tripleorocky/heat-docker-agents-centos:latest
   push_destination: localhost:8787
@@ -167,14 +173,14 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'namespace': 'docker.io/tripleorocky',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v3.0.3-stable-3.0-luminous-centos-7-x86_64',
+                'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
                 'neutron_driver': None,
                 'openshift_namespace': 'docker.io/openshift',
-                'openshift_tag': 'v3.9.0',
-                'openshift_base_image': 'origin',
+                'openshift_tag': 'v3.11.0',
+                'openshift_prefix': 'origin',
                 'openshift_cockpit_namespace': 'docker.io/cockpit',
                 'openshift_cockpit_image': 'kubernetes',
                 'openshift_cockpit_tag': 'latest',
@@ -189,6 +195,42 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_heketi_namespace': 'docker.io/heketi',
                 'openshift_heketi_image': 'heketi',
                 'openshift_heketi_tag': 'latest',
+                'openshift_asb_namespace': 'docker.io/ansibleplaybookbundle',
+                'openshift_asb_tag': 'latest',
+                'openshift_cluster_monitoring_namespace':
+                    'docker.io/tripleorocky',
+                'openshift_cluster_monitoring_image':
+                    'coreos-cluster-monitoring-operator',
+                'openshift_cluster_monitoring_tag': 'v0.1.1',
+                'openshift_configmap_reload_namespace':
+                    'docker.io/tripleorocky',
+                'openshift_configmap_reload_image': 'coreos-configmap-reload',
+                'openshift_configmap_reload_tag': 'v0.0.1',
+                'openshift_prometheus_operator_namespace':
+                    'docker.io/tripleorocky',
+                'openshift_prometheus_operator_image':
+                    'coreos-prometheus-operator',
+                'openshift_prometheus_operator_tag': 'v0.23.2',
+                'openshift_prometheus_config_reload_namespace':
+                    'docker.io/tripleorocky',
+                'openshift_prometheus_config_reload_image':
+                    'coreos-prometheus-config-reloader',
+                'openshift_prometheus_config_reload_tag': 'v0.23.2',
+                'openshift_prometheus_tag': 'v2.3.2',
+                'openshift_prometheus_alertmanager_tag': 'v0.15.2',
+                'openshift_prometheus_node_exporter_tag': 'v0.16.0',
+                'openshift_oauth_proxy_tag': 'v1.1.0',
+                'openshift_kube_rbac_proxy_namespace':
+                    'docker.io/tripleorocky',
+                'openshift_kube_rbac_proxy_image': 'coreos-kube-rbac-proxy',
+                'openshift_kube_rbac_proxy_tag': 'v0.3.1',
+                'openshift_kube_state_metrics_namespace':
+                    'docker.io/tripleorocky',
+                'openshift_kube_state_metrics_image':
+                    'coreos-kube-state-metrics',
+                'openshift_kube_state_metrics_tag': 'v1.3.1',
+                'openshift_grafana_namespace': 'docker.io/grafana',
+                'openshift_grafana_tag': '5.2.1',
             },
             builder.container_images_template_inputs()
         )
@@ -204,8 +246,8 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'tag': 'rocky',
                 'neutron_driver': 'ovn',
                 'openshift_namespace': 'docker.io/openshift3',
-                'openshift_tag': 'v3.10.0',
-                'openshift_base_image': 'ose',
+                'openshift_tag': 'v3.11.0',
+                'openshift_prefix': 'ose',
                 'openshift_cockpit_namespace': 'docker.io/openshift-cockpit',
                 'openshift_cockpit_image': 'cockpit',
                 'openshift_cockpit_tag': 'cockpit-tag',
@@ -213,15 +255,52 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_etcd_image': 'openshift-etcd',
                 'openshift_etcd_tag': 'etcd-tag',
                 'openshift_gluster_namespace':
-                'registry.access.redhat.com/rhgs3',
+                    'registry.access.redhat.com/rhgs3',
                 'openshift_gluster_image': 'rhgs-server-rhel7',
                 'openshift_gluster_block_image':
-                'rhgs-gluster-block-prov-rhel7',
+                    'rhgs-gluster-block-prov-rhel7',
                 'openshift_gluster_tag': 'gluster-tag',
                 'openshift_heketi_namespace':
-                'registry.access.redhat.com/rhgs3',
+                    'registry.access.redhat.com/rhgs3',
                 'openshift_heketi_image': 'rhgs-volmanager-rhel7',
                 'openshift_heketi_tag': 'heketi-tag',
+                'openshift_asb_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_asb_tag': 'v3.11',
+                'openshift_cluster_monitoring_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_cluster_monitoring_image':
+                    'ose-cluster-monitoring-operator',
+                'openshift_cluster_monitoring_tag': 'v3.11',
+                'openshift_configmap_reload_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_configmap_reload_image': 'ose-configmap-reloader',
+                'openshift_configmap_reload_tag': 'v3.11',
+                'openshift_prometheus_operator_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_prometheus_operator_image':
+                    'ose-prometheus-operator',
+                'openshift_prometheus_operator_tag': 'v3.11',
+                'openshift_prometheus_config_reload_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_prometheus_config_reload_image':
+                    'ose-prometheus-config-reloader',
+                'openshift_prometheus_config_reload_tag': 'v3.11',
+                'openshift_prometheus_tag': 'v3.11',
+                'openshift_prometheus_alertmanager_tag': 'v3.11',
+                'openshift_prometheus_node_exporter_tag': 'v3.11',
+                'openshift_oauth_proxy_tag': 'v3.11',
+                'openshift_kube_rbac_proxy_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_kube_rbac_proxy_image': 'ose-kube-rbac-proxy',
+                'openshift_kube_rbac_proxy_tag': 'v3.11',
+                'openshift_kube_state_metrics_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_kube_state_metrics_image': 'ose-kube-state-metrics',
+                'openshift_kube_state_metrics_tag': 'v3.11',
+                'openshift_grafana_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_grafana_tag': 'v3.11',
             },
             builder.container_images_template_inputs(
                 namespace='192.0.2.0:5000/tripleorocky',
@@ -233,8 +312,8 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 tag='rocky',
                 neutron_driver='ovn',
                 openshift_namespace='docker.io/openshift3',
-                openshift_tag='v3.10.0',
-                openshift_base_image='ose',
+                openshift_tag='v3.11.0',
+                openshift_prefix='ose',
                 openshift_cockpit_namespace='docker.io/openshift-cockpit',
                 openshift_cockpit_image='cockpit',
                 openshift_cockpit_tag='cockpit-tag',
@@ -248,6 +327,43 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 openshift_heketi_namespace='registry.access.redhat.com/rhgs3',
                 openshift_heketi_image='rhgs-volmanager-rhel7',
                 openshift_heketi_tag='heketi-tag',
+                openshift_asb_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_asb_tag='v3.11',
+                openshift_cluster_monitoring_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_cluster_monitoring_image='ose-'
+                    'cluster-monitoring-operator',
+                openshift_cluster_monitoring_tag='v3.11',
+                openshift_configmap_reload_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_configmap_reload_image='ose-configmap-reloader',
+                openshift_configmap_reload_tag='v3.11',
+                openshift_prometheus_operator_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_prometheus_operator_image='ose-'
+                    'prometheus-operator',
+                openshift_prometheus_operator_tag='v3.11',
+                openshift_prometheus_config_reload_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_prometheus_config_reload_image='ose-'
+                    'prometheus-config-reloader',
+                openshift_prometheus_config_reload_tag='v3.11',
+                openshift_prometheus_tag='v3.11',
+                openshift_prometheus_alertmanager_tag='v3.11',
+                openshift_prometheus_node_exporter_tag='v3.11',
+                openshift_oauth_proxy_tag='v3.11',
+                openshift_kube_rbac_proxy_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_kube_rbac_proxy_image='ose-kube-rbac-proxy',
+                openshift_kube_rbac_proxy_tag='v3.11',
+                openshift_kube_state_metrics_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_kube_state_metrics_image='ose-kube-state-metrics',
+                openshift_kube_state_metrics_tag='v3.11',
+                openshift_grafana_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_grafana_tag='v3.11',
             )
         )
 
@@ -603,12 +719,15 @@ class TestPrepare(base.TestCase):
                 template_file=TEMPLATE_PATH,
                 output_env_file=constants.CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
-                service_filter=['OS::TripleO::Services::NeutronServer'],
+                service_filter=[
+                    'OS::TripleO::Services::NeutronServer'
+                ],
                 mapping_args={
                     'namespace': 't',
                     'name_prefix': 'p',
                     'name_suffix': '',
                     'tag': 'l',
+                    'neutron_driver': None
                 }
             )
         )
@@ -639,6 +758,7 @@ class TestPrepare(base.TestCase):
                     'name_prefix': 'p',
                     'name_suffix': '',
                     'tag': 'l',
+                    'neutron_driver': 'ovn'
                 }
             )
         )
@@ -669,6 +789,7 @@ class TestPrepare(base.TestCase):
                     'name_prefix': '',
                     'name_suffix': '',
                     'tag': 'l',
+                    'neutron_driver': 'odl'
                 }
             )
         )
@@ -1005,3 +1126,32 @@ class TestPrepare(base.TestCase):
             },
             image_params
         )
+
+    def test_set_neutron_driver(self):
+        mapping_args = {}
+        kb.set_neutron_driver(None, mapping_args)
+        self.assertNotIn('neutron_driver', mapping_args)
+
+        mapping_args = {}
+        kb.set_neutron_driver({}, mapping_args)
+        self.assertNotIn('neutron_driver', mapping_args)
+
+        mapping_args = {}
+        kb.set_neutron_driver(
+            {'NeutronMechanismDrivers': ['sriovnicswitch', 'openvswitch']},
+            mapping_args
+        )
+        self.assertNotIn('neutron_driver', mapping_args)
+
+        mapping_args = {}
+        kb.set_neutron_driver(
+            {'NeutronMechanismDrivers': ['ovn']},
+            mapping_args
+        )
+        self.assertEqual('ovn', mapping_args['neutron_driver'])
+        mapping_args = {}
+        kb.set_neutron_driver(
+            {'NeutronMechanismDrivers': ['sriovnicswitch', 'opendaylight_v2']},
+            mapping_args
+        )
+        self.assertEqual('odl', mapping_args['neutron_driver'])
